==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/gwt/js/JsMessageBodyPart.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.backend.mail.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsMessageBodyPart extends JavaScriptObject {

	protected JsMessageBodyPart() {}

	public final native String getMime()
	/*-{
	return this["mime"];
	}-*/;

	public final native void setMime(String mime)
	/*-{
       this["mime"] = mime;
	}-*/;

	public final native String getAddress()
	/*-{
	return this["address"];
	}-*/;

	public final native void setAddress(String address)
	/*-{
       this["address"] = address;
	}-*/;

	public final native String getEncoding()
	/*-{
	return this["encoding"];
	}-*/;

	public final native void setEncoding(String encoding)
	/*-{
       this["encoding"] = encoding;
	}-*/;

	public final native String getCharset()
	/*-{
	return this["charset"];
	}-*/;

	public final native void setCharset(String charset)
	/*-{
       this["charset"] = charset;
	}-*/;

	public final native String getFileName()
	/*-{
	return this["fileName"];
	}-*/;

	public final native void setFileName(String fileName)
	/*-{
       this["fileName"] = fileName;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyHeader> getHeaders()
	/*-{
	return this["headers"];
	}-*/;

	public final native void setHeaders(com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyHeader> headers)
	/*-{
       this["headers"] = headers;
	}-*/;

	public final native String getContentId()
	/*-{
	return this["contentId"];
	}-*/;

	public final native void setContentId(String contentId)
	/*-{
       this["contentId"] = contentId;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyPart> getChildren()
	/*-{
	return this["children"];
	}-*/;

	public final native void setChildren(com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyPart> children)
	/*-{
       this["children"] = children;
	}-*/;

	public final native int getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(int size)
	/*-{
       this["size"] = size;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsDispositionType getDispositionType()
	/*-{
	return this["dispositionType"];
	}-*/;

	public final native void setDispositionType(net.bluemind.backend.mail.api.gwt.js.JsDispositionType dispositionType)
	/*-{
       this["dispositionType"] = dispositionType;
	}-*/;

	public static native  JsMessageBodyPart create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.platform-5.4.2696.zip: net/bluemind/backend/mail/api/gwt/js/JsMessageBodyPart.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.backend.mail.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsMessageBodyPart extends JavaScriptObject {

	protected JsMessageBodyPart() {}

	public final native String getMime()
	/*-{
	return this["mime"];
	}-*/;

	public final native void setMime(String mime)
	/*-{
       this["mime"] = mime;
	}-*/;

	public final native net.bluemind.core.commons.gwt.JsMapStringString getMimeParameters()
	/*-{
	return this["mimeParameters"];
	}-*/;

	public final native void setMimeParameters(net.bluemind.core.commons.gwt.JsMapStringString mimeParameters)
	/*-{
       this["mimeParameters"] = mimeParameters;
	}-*/;

	public final native String getAddress()
	/*-{
	return this["address"];
	}-*/;

	public final native void setAddress(String address)
	/*-{
       this["address"] = address;
	}-*/;

	public final native String getEncoding()
	/*-{
	return this["encoding"];
	}-*/;

	public final native void setEncoding(String encoding)
	/*-{
       this["encoding"] = encoding;
	}-*/;

	public final native String getCharset()
	/*-{
	return this["charset"];
	}-*/;

	public final native void setCharset(String charset)
	/*-{
       this["charset"] = charset;
	}-*/;

	public final native String getFileName()
	/*-{
	return this["fileName"];
	}-*/;

	public final native void setFileName(String fileName)
	/*-{
       this["fileName"] = fileName;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyHeader> getHeaders()
	/*-{
	return this["headers"];
	}-*/;

	public final native void setHeaders(com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyHeader> headers)
	/*-{
       this["headers"] = headers;
	}-*/;

	public final native String getContentId()
	/*-{
	return this["contentId"];
	}-*/;

	public final native void setContentId(String contentId)
	/*-{
       this["contentId"] = contentId;
	}-*/;

	public final native String getHash()
	/*-{
	return this["hash"];
	}-*/;

	public final native void setHash(String hash)
	/*-{
       this["hash"] = hash;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyPart> getChildren()
	/*-{
	return this["children"];
	}-*/;

	public final native void setChildren(com.google.gwt.core.client.JsArray<net.bluemind.backend.mail.api.gwt.js.JsMessageBodyPart> children)
	/*-{
       this["children"] = children;
	}-*/;

	public final native int getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(int size)
	/*-{
       this["size"] = size;
	}-*/;

	public final native net.bluemind.backend.mail.api.gwt.js.JsDispositionType getDispositionType()
	/*-{
	return this["dispositionType"];
	}-*/;

	public final native void setDispositionType(net.bluemind.backend.mail.api.gwt.js.JsDispositionType dispositionType)
	/*-{
       this["dispositionType"] = dispositionType;
	}-*/;

	public static native  JsMessageBodyPart create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
